import { createRoot } from 'react-dom/client'
import { useState, useRef } from 'react'
import { VRCanvas, Hands, useXR, Interactive, useHitTest, DefaultXRControllers } from '@react-three/xr'
import { Box, Text } from '@react-three/drei'
import { useFrame } from '@react-three/fiber'

function Button(props) {
  const [hover, setHover] = useState(false)
  const [color, setColor] = useState(0x123456)

  return (
    <Interactive onSelect={() => setColor((Math.random() * 0xffffff) | 0)} onHover={() => setHover(true)} onBlur={() => setHover(false)}>
      <Box scale={hover ? [1.5, 1.5, 1.5] : [1, 1, 1]} args={[0.4, 0.1, 0.1]} {...props}>
        <meshStandardMaterial attach="material" color={color} />
        {false && (
          <Text position={[0, 0, 0.06]} fontSize={0.05} color="#000" anchorX="center" anchorY="middle">
            Hello react-xr!
          </Text>
        )}
      </Box>
    </Interactive>
  )
}

function PlayerExample() {
  const player = useXR((state) => state.player)
  useFrame(() => void (player.rotation.x = player.rotation.y += 0.01))

  return null
}

function HitTestExample() {
  const boxRef = useRef()
  useHitTest((hitMatrix) => boxRef.current.applyMatrix4(hitMatrix))

  return <Box ref={boxRef} args={[0.1, 0.1, 0.1]} />
}

function App() {
  return (
    <VRCanvas>
      <ambientLight intensity={0.5} />
      <pointLight position={[5, 5, 5]} />
      <Hands
      // modelLeft="/hand-left.gltf"
      // modelRight="/hand-right.gltf"
      />
      <Button position={[0, 0.8, -1]} />
      <DefaultXRControllers />
      {false && <PlayerExample />}
      {false && <HitTestExample />}
    </VRCanvas>
  )
}

const root = createRoot(document.querySelector('#root'))
root.render(<App />)
